aboutsummaryrefslogtreecommitdiff
path: root/keyboards/ymdk/yd60mq/yd60mq.c
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/ymdk/yd60mq/yd60mq.c')
-rw-r--r--keyboards/ymdk/yd60mq/yd60mq.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/keyboards/ymdk/yd60mq/yd60mq.c b/keyboards/ymdk/yd60mq/yd60mq.c
index 1a14040907..40c899c46f 100644
--- a/keyboards/ymdk/yd60mq/yd60mq.c
+++ b/keyboards/ymdk/yd60mq/yd60mq.c
@@ -2,20 +2,20 @@
__attribute__((weak))
void matrix_init_kb(void){
- setPinOutput(F4);
- writePinHigh(F4);
+ gpio_set_pin_output(F4);
+ gpio_write_pin_high(F4);
}
__attribute__((weak))
bool led_update_kb(led_t led_state) {
bool res = led_update_user(led_state);
if (res) {
// writePin sets the pin high for 1 and low for 0.
// In this example the pins are inverted, setting
// it low/0 turns it on, and high/1 turns the LED off.
// This behavior depends on whether the LED is between the pin
// and VCC or the pin and GND.
- writePin(F4, !led_state.caps_lock);
+ gpio_write_pin(F4, !led_state.caps_lock);
}
return res;
}
@@ -2,20 +2,20 @@
bool res = led_update_user(led_state);
if (res) {
- // writePin sets the pin high for 1 and low for 0.
+ // gpio_write_pin sets the pin high for 1 and low for 0.
// In this example the pins are inverted, setting
// it low/0 turns it on, and high/1 turns the LED off.